#  tests for murmurhash-1.0.2-py37he6710b0_0 (this is a generated file);
print('===== testing package: murmurhash-1.0.2-py37he6710b0_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import murmurhash
import os
import pytest

PACKAGE_DIR = os.path.abspath(os.path.dirname(murmurhash.__file__))
pytest.main([PACKAGE_DIR])
#  --- run_test.py (end) ---

print('===== murmurhash-1.0.2-py37he6710b0_0 OK =====');
